// Load DataQJPS.dta
clear all
set more off

//root folder, for example
//cd "C:\Supplementary material\Replication package"

use "DataQJPS.dta", clear

********************************************************************************
********************************Paper*******************************************
********************************************************************************

// Except for Figure 1. Game Tree, all Figures and Tables in the paper come from the code below.


//Table 1
tab Treatment Democrats if Treatmen<=6
****

****
//Table 2
estpost ttest keep /// 
              Female ///
			  White Black ///
			  Married ///
			  AtLeastCollege ///
			  NotWorking ///
			  Between75k_150k Between150k_350k More350k ///
			  YOB_* ///
			  ScoreCRT ///
			  Conservative VeryConservative ///   
              if Treatment<=6, by(Democrats) 

esttab ., wide cell("N_1 mu_1(fmt(2)) N_2 mu_2(fmt(2)) b(fmt(2)) se(fmt(2)) p(fmt(2))") tex 
esttab ., wide cell("N_1 mu_1(fmt(2)) N_2 mu_2(fmt(2)) b(fmt(2)) se(fmt(2)) p(fmt(2))") // mu_1 and mu_2 are the means reported in the paper, b is diff and p is the t-test p-value
esttab ., wide // Only t statistic reported with stars for significance
eststo clear


****
//Table 3
//Dem 
estpost tabstat Trust p /// 
              if Democrats==1 & Treatment<=6, by(Treatment) columns(statistics) listwise ///
              statistics(mean sd) 


esttab ., main(mean) aux(sd) nostar unstack b( %12.2f) ///
          noobs nonote label 
esttab ., main(mean) aux(sd) nostar unstack b( %12.2f) ///
          noobs nonote label tex
eststo clear

//Rep 
estpost tabstat Trust p /// 
              if  Democrats==0 & Treatment<=6, by(Treatment) columns(statistics) listwise ///
              statistics(mean sd) 


esttab ., main(mean) aux(sd) nostar unstack b( %12.2f) ///
          noobs nonote label 
esttab ., main(mean) aux(sd) nostar unstack b( %12.2f) ///
          noobs nonote label tex // Note the Democrat-Republican comuns are inverted
eststo clear

***Statistical tests associated with Table 3

// Overall, across Democrats and Republicans
*Trust behavior
tab Democrats Trust if Treatment<=6, row chi
*Trust beliefs
ranksum p  if Treatment<=6, by(Democrats) // two sided test because I have no prior

//Democrat Player A
// D vs R Player B
*Trust behavior
tab Treatment Trust if Democrats==1&(Treatment==1|Treatment==2|Treatment==3), row chi
*Trust beliefs
ranksum p if Democrats==1&(Treatment==2|Treatment==3), by(Treatment) 
display 1 - normal(r(z))

//Republican Player A
// D vs R Player B
*Trust behavior
tab Treatment Trust if Democrats==0&(Treatment==4|Treatment==5|Treatment==6), row chi
*Trust beliefs
ranksum p if Democrats==0&(Treatment==5|Treatment==6), by(Treatment) 
display 1 - normal(r(z))

// Differences from other pairwise comparisons for Republican Players A
// Difference in trust behavior
tab Treatment Trust if Democrats==0&(Treatment==4|Treatment==5), row chi
tab Treatment Trust if Democrats==0&(Treatment==4|Treatment==6), row chi
// Difference in distribution of trust beliefs
ranksum p if Democrats==0&(Treatment==4|Treatment==5), by(Treatment)
display 1 - normal(-r(z))
ranksum p if Democrats==0&(Treatment==4|Treatment==6), by(Treatment) // two sided test because I have no prior.

****

****

//Table 4

set more off

eststo: reg p Is ///
              keep /// 
              Female ///
			  White Black ///
			  Married ///
			  AtLeastCollege ///
			  NotWorking ///
			  Between75k_150k Between150k_350k More350k ///
			  YOB_* ///
			  ScoreCRT ///
			  Conservative VeryConservative ///    
			  if  Treatment==2 | Treatment==3
			  
eststo: reg p Is College Is_x_College if Treatment==2 | Treatment==3
test _b[Is] + _b[Is_x_College]=0
estadd scalar pv = r(p)
			  
eststo: reg p Is more75k Is_x_Income if  Treatment==2 | Treatment==3
test _b[Is] + _b[Is_x_Income]=0
estadd scalar pv = r(p)	

eststo: reg p Is CRT34 Is_x_CRT34   if Treatment==2 | Treatment==3
test _b[Is] + _b[Is_x_CRT34]=0
estadd scalar pv = r(p) // Ho: _b[Is] + _b[Is_x_CRT34]=0, F stat p-value. (Two-sided test because no prior)
		  
eststo: reg p Is ///
              keep /// 
              Female ///
			  White Black ///
			  Married ///
			  AtLeastCollege ///
			  NotWorking ///
			  Between75k_150k Between150k_350k More350k ///
			  YOB_* ///
			  ScoreCRT ///
			  Conservative VeryConservative ///    
			  if  Treatment==5 | Treatment==6
			  
eststo: reg p Is College Is_x_College if Treatment==5 | Treatment==6 
test _b[Is] + _b[Is_x_College]=0
estadd scalar pv  = r(p)

eststo: reg p Is more75k Is_x_Income if  Treatment==5 | Treatment==6 
test _b[Is] + _b[Is_x_Income]=0
estadd scalar pv  = r(p)
			  
eststo: reg p Is CRT34 Is_x_CRT34   if Treatment==5 | Treatment==6
test _b[Is] + _b[Is_x_CRT34]=0
estadd scalar pv  = r(p)

** Add PBD: Player B Democrat dummy **
eststo: reg p Is PBD if  Treatment==2 | Treatment==3 |  Treatment==5 | Treatment==6 
			  
esttab, r2 se star (** 0.05 *** 0.01)  b( %12.2f) scalar(pv) drop(keep /// 
              Female ///
			  White Black ///
			  Married ///
			  AtLeastCollege ///
			  NotWorking ///
			  Between75k_150k Between150k_350k More350k ///
			  YOB_* ///
			  ScoreCRT ///
			  Conservative VeryConservative)
			  
esttab using "Table 4.csv", replace r2 se nostar scalar(pv)  b( %12.2f) drop(              keep /// 
              Female ///
			  White Black ///
			  Married ///
			  AtLeastCollege ///
			  NotWorking ///
			  Between75k_150k Between150k_350k More350k ///
			  YOB_* ///
			  ScoreCRT ///
			  Conservative VeryConservative) 
eststo clear


// Strong political identity (results in footnote 14 in the text)
eststo: reg p Is if  (Treatment==2 | Treatment==3) & stronglyDemocratAlt==1			  
eststo: reg p Is if  (Treatment==5 | Treatment==6) & stronglyRepublicanAlt==1	
esttab, r2 se star(* 0.10 ** 0.05 *** 0.01)  b( %12.2f)
eststo clear


****
// Table 5
eststo: reg Trust p if Treatment==2
eststo: reg Trust p if Treatment==3

eststo: reg Trust p if Treatment==6
eststo: reg Trust p if Treatment==5

eststo: reg Trust p if (Treatment==2 | Treatment==5) & ScoreCRT34==1
eststo: reg Trust p if (Treatment==3 | Treatment==6) & ScoreCRT34==1

esttab, r2 se star (* 0.1 ** 0.05 *** 0.01)  b( %12.2f) scalar() drop()
			  
esttab using "Table 5.csv", append r2 se nostar scalar()  b( %12.2f) drop() 
eststo clear

// Reported in footnote 16
eststo: reg Trust p if  Treatment==1
eststo: reg Trust p if  Treatment==4			  		  

esttab, r2 se star(* 0.10 ** 0.05 *** 0.01)  b( %12.2f) drop()
eststo clear
		  
// Reported in footnote 17
// Adding belief treatment dummy
eststo: reg Trust p BeliefsTreatment if (Treatment==2 | Treatment==5 | Treatment==11 | Treatment==13) & ScoreCRT34==1
eststo: reg Trust p BeliefsTreatment if (Treatment==3 | Treatment==6 | Treatment==12 | Treatment==14) & ScoreCRT34==1

esttab, r2 se star (* 0.1 ** 0.05 *** 0.01)  b( %12.2f) scalar() drop()
eststo clear

// Seemingly unrelated regression
// Comparison across regressions (Columns 1 to 4))
quietly: reg Trust p if Treatment==2 
est store treat2
quietly: reg Trust p if Treatment==3
est store treat3

quietly: reg Trust p if Treatment==5 
est store treat5
quietly: reg Trust p if Treatment==6 
est store treat6

suest treat*, vce(robust)

//Beliefs
test [treat2_mean]p=[treat3_mean]p
display "H_0: Belief coeff D-D >= Belief coeff D-R p-value = " 1- normal(sqrt(r(chi2)))

test [treat5_mean]p=[treat6_mean]p
display "H_0: Belief coeff R-R >= Belief coeff R-D p-value = " 1- normal(sqrt(r(chi2)))
est clear

// Columns (5 and 6)
reg Trust p if (Treatment ==2 | Treatment ==5) & ScoreCRT34==1
est store streat25

reg Trust p if (Treatment ==3 | Treatment ==6) & ScoreCRT34==1
est store streat36

suest streat25 streat36, vce(robust)

//Beliefs
test [streat25_mean]p=[streat36_mean]p
display "H_0: Belief coeff Same >= Belief coeff Other p-value = " 1- normal(sqrt(r(chi2)))
est clear

*****
// Table 6
// (Note format of Table 6 is not directly programmed in Stata)

// First row
estpost tabstat p /// 
              if  Treatment==2 | Treatment==3, by(Treatment) columns(statistics) listwise ///
              statistics(mean sd) 

esttab ., main(mean) aux(sd) nostar unstack b( %12.2f) ///
          noobs nonote label 
eststo clear

// Second row
tab Trustworthy if Treatment==2	// Trustworthiness of a Democrat   Player B matched to a Democrat Player A	  
tab Trustworthy if Treatment==6 // Trustworthiness of a Republican Player B matched to a Democrat Player A	
tab Trustworthy if Treatment<=6 // Trustworthiness over all

// Third row
estpost tabstat p /// 
              if  Treatment==5 | Treatment==6, by(Treatment) columns(statistics) listwise ///
              statistics(mean sd) 

esttab ., main(mean) aux(sd) nostar unstack b( %12.2f) /// Note Republican matched Republican comes first
          noobs nonote label 
		  
eststo clear

// Fourth row
tab Trustworthy if Treatment==3	// Trustworthiness of a Democrat   Player B matched to a Republican Player A	  
tab Trustworthy if Treatment==5 // Trustworthiness of a Republican Player B matched to a Republican Player A	
tab Trustworthy if Treatment<=6 // Trustworthiness over all

// Statistical tests in the paper
// Reciprocation by Democrats vs Republicans when Player A is Democrat
tabi 85 15 \ 41 3, chi

// Reciprocation by Democrats vs Republicans when Player A is Republican
tabi 38 9 \ 86 13, chi

// Identity of player B fixed
// Player B Democrat
tabi 38 9 \ 85 15, chi

// Player B Republican
tabi 86 13 \ 41 3, chi


****
//Figure 2
//DD

// Test 
ranksum  p if (Treatment==2|Treatment==11), by(Treatment)
display  1 - normal(-r(z))

twoway (hist p if Treatment==2, discrete bcolor(gs7) barwidth(0.08) percent) ///
       (hist p if Treatment==11, discrete bcolor(gs12) barwidth(0.06) percent), ///
	   title("Panel 1. Democrat Player B") ///
	   xtitle("Forecasted reciprocation rate" " ") ///
	   legend(order(1 "Baseline" 2 "Actual trustworthiness revealed") pos(10) ring(0) col(1) size(2.5)) ///
	   graphregion(fcolor(white)) plotregion(fcolor(white)) xline(0.85) ///
	   saving(11, replace) 
 

//DR
ranksum  p if (Treatment==3|Treatment==12), by(Treatment)
display  1 - normal(-r(z))

twoway (hist p if Treatment==3, discrete bcolor(gs7) barwidth(0.08) percent) ///
       (hist p if Treatment==12, discrete bcolor(gs12) barwidth(0.06) percent), ///
	   title("Panel 2. Republican Player B") ///
	   xtitle("Forecasted reciprocation rate" " ") ///
       legend(off) ///
	   graphregion(fcolor(white)) plotregion(fcolor(white)) ///
	   yscale(range(0(10)50)) ylabel(0(10)50) xline(0.93) ///
	   saving(12, replace) 

graph combine 11.gph 12.gph, graphregion(fcolor(white)) plotregion(fcolor(white))
graph export "Democrat-belief.png", replace
graph export "Democrat-belief.eps", replace
 
****
// Figure 3
// RR
ranksum  p if (Treatment==5|Treatment==13), by(Treatment)
display  1 - normal(-r(z))
	   
twoway (hist p if Treatment==5, discrete bcolor(gs7) barwidth(0.08) percent) ///
       (hist p if Treatment==13, discrete bcolor(gs12) barwidth(0.06) percent), ///
	   title("Panel 2. Republican Player B") ///
	   xtitle("Forecasted reciprocation rate" " ") ///
	   legend(off) ///
	   graphregion(fcolor(white)) plotregion(fcolor(white)) ///
	   yscale(range(0(10)50)) ylabel(0(10)50) xline(0.87) ///
	   saving(22, replace) 
       	     
//RD	   
ranksum  p if (Treatment==6|Treatment==14), by(Treatment)
display  1 - normal(-r(z))

twoway (hist p if Treatment==6, discrete bcolor(gs7) barwidth(0.08) percent) ///
       (hist p if Treatment==14, discrete bcolor(gs12) barwidth(0.06) percent), ///
	   title("Panel 1. Democrat Player B") ///
	   xtitle("Forecasted reciprocation rate" " ") ///
       legend(order(1 "Baseline" 2 "Actual trustworthiness revealed") pos(10) ring(0) col(1) size(2.5)) ///
	   graphregion(fcolor(white)) plotregion(fcolor(white)) ///
	   yscale(range(0(10)50)) ylabel(0(10)50) xline(0.81) ///
	   saving(21, replace) 
	   	   
	   
graph combine 21.gph 22.gph, graphregion(fcolor(white)) plotregion(fcolor(white))
graph export "Republican-belief.png", replace
graph export "Republican-belief.eps", replace


*****************************
******ONLINE APPENDIX********
*****************************

***
//Table 1
tab Democrats basedonyourpoliticalviewswouldyo if Treatment<=6, row

//Table 2
//Stata format not exactly as Table 2 in online appendix.
tab Treatment basedonyourpoliticalviewswouldyo if Democrats==1 & Treatment<=6, miss row // Note that Independent and Other are combined in the Online Appendix
tab Treatment basedonyourpoliticalviewswouldyo if Democrats==0 & Treatment<=6, miss row // Note that last two rows are swapped in the online appendix

//Table 3
// All interactions
set more off

//D			  
eststo: reg p Is CRT34 Is_x_CRT34   if Treatment==2 | Treatment==3
test _b[Is] + _b[Is_x_CRT34]=0
estadd scalar pv = r(p) // Ho: _b[Is] + _b[Is_x_CRT34]=0, F stat p-value. (Two-sided test because no prior)

eststo: reg p Is College Is_x_College if Treatment==2 | Treatment==3
test _b[Is] + _b[Is_x_College]=0
estadd scalar pv = r(p)

eststo: reg p Is more75k Is_x_Income if  Treatment==2 | Treatment==3
test _b[Is] + _b[Is_x_Income]=0
estadd scalar pv = r(p)	

eststo: reg p Is Age Is_x_Age   if Treatment==2 | Treatment==3
test _b[Is] + _b[Is_x_Age]=0
estadd scalar pv  = r(p)

eststo: reg p Is Female_ Is_x_Female if Treatment==2 | Treatment==3 
test _b[Is] + _b[Is_x_Female]=0
estadd scalar pv  = r(p)

eststo: reg p Is giving Is_x_Altruism if  Treatment==2 | Treatment==3 
test _b[Is] + _b[Is_x_Altruism]=0
estadd scalar pv  = r(p)
		  
//R			  
eststo: reg p Is CRT34 Is_x_CRT34   if Treatment==5 | Treatment==6
test _b[Is] + _b[Is_x_CRT34]=0
estadd scalar pv  = r(p)

eststo: reg p Is College Is_x_College if Treatment==5 | Treatment==6 
test _b[Is] + _b[Is_x_College]=0
estadd scalar pv  = r(p)

eststo: reg p Is more75k Is_x_Income if  Treatment==5 | Treatment==6 
test _b[Is] + _b[Is_x_Income]=0
estadd scalar pv  = r(p)

eststo: reg p Is Age Is_x_Age    if Treatment==5 | Treatment==6
test _b[Is] + _b[Is_x_Age]=0
estadd scalar pv  = r(p)

eststo: reg p Is Female_ Is_x_Female if Treatment==5 | Treatment==6 
test _b[Is] + _b[Is_x_Female]=0
estadd scalar pv  = r(p)

eststo: reg p Is giving Is_x_Altruism if  Treatment==5 | Treatment==6 
test _b[Is] + _b[Is_x_Altruism]=0
estadd scalar pv  = r(p)

		  

esttab, r2 se star (** 0.05 *** 0.01)  b( %12.2f) scalar(pv) drop()	  
esttab using "OA - Table 3.csv", replace r2 se nostar scalar(pv)  b( %12.2f) drop() 
eststo clear
		  



// Section 5:  A preference channel for identity
// Comparison constant across regressions (Columns 1 to 4) in Table 5 in paper)
quietly: reg Trust p if Treatment==2 
est store treat2
quietly: reg Trust p if Treatment==3
est store treat3

quietly: reg Trust p if Treatment==5 
est store treat5
quietly: reg Trust p if Treatment==6 
est store treat6

suest treat*, vce(robust)

//Constants
test [treat2_mean]_cons=[treat3_mean]_cons
display "H_0: M(I) D-D >= M(I) D-R p-value = " 1- normal(sqrt(r(chi2)))

test [treat5_mean]_cons=[treat6_mean]_cons
display "H_0: M(I) R-R >= M(I) R-D p-value = " 1- normal(sqrt(r(chi2)))
est clear

// Trust (very pessimistic individuals)
tab Trust Is if (Treatment==2 | Treatment==3) & p<=.19, row col chi
tab Trust Is if (Treatment==2 | Treatment==3) & p<=.29, row col chi
tab Trust Is if (Treatment==2 | Treatment==3) & p<=.39, row col chi

tab Trust Is if (Treatment==5 | Treatment==6) & p<=.19, row col chi
tab Trust Is if (Treatment==5 | Treatment==6) & p<=.29, row col chi
tab Trust Is if (Treatment==5 | Treatment==6) & p<=.39, row col chi

// What if we only look at the conservative republicans
tab Trust Is if (Treatment==2 | Treatment==3) & p<=.19 ///
              & (polorientation=="1 Very Liberal" | polorientation=="2 Liberal"), row col chi
tab Trust Is if (Treatment==2 | Treatment==3) & p<=.29 ///
              & (polorientation=="1 Very Liberal" | polorientation=="2 Liberal"), row col chi
tab Trust Is if (Treatment==2 | Treatment==3) & p<=.39 ///
              & (polorientation=="1 Very Liberal" | polorientation=="2 Liberal"), row col chi			  
			  
tab Trust Is if (Treatment==5 | Treatment==6) & p<=.19 /// Only one observation
              & (polorientation=="4 Conservative" | polorientation=="5 Very Conservative"), row col chi
tab Trust Is if (Treatment==5 | Treatment==6) & p<=.29 ///
              & (polorientation=="4 Conservative" | polorientation=="5 Very Conservative"), row col chi			  
tab Trust Is if (Treatment==5 | Treatment==6) & p<=.39 ///
              & (polorientation=="4 Conservative" | polorientation=="5 Very Conservative"), row col chi		


			  
			  
*****
// Table 4
// DD			  
eststo: reg p BT CRT34 BT_x_CRT34   if Treatment==2 | Treatment==11
test _b[BT] + _b[BT_x_CRT34]=0
estadd scalar pv = r(p) // Ho: _b[BT] + _b[BT_x_CRT34]=0, F stat p-value. (Two-sided test because no prior)

eststo: reg p BT College BT_x_College if Treatment==2 | Treatment==11
test _b[BT] + _b[BT_x_College]=0
estadd scalar pv = r(p)

eststo: reg p BT more75k BT_x_Income if  Treatment==2 | Treatment==11
test _b[BT] + _b[BT_x_Income]=0
estadd scalar pv = r(p)

eststo: reg p BT Age BT_x_Age   if Treatment==2 | Treatment==11
test _b[BT] + _b[BT_x_Age]=0
estadd scalar pv  = r(p)

eststo: reg p BT Female BT_x_Female if Treatment==2 | Treatment==11 
test _b[BT] + _b[BT_x_Female]=0
estadd scalar pv  = r(p)

eststo: reg p BT giving BT_x_Altruism if  Treatment==2 | Treatment==11 
test _b[BT] + _b[BT_x_Altruism]=0
estadd scalar pv  = r(p)	

//DR
eststo: reg p BT CRT34 BT_x_CRT34   if Treatment==3 | Treatment==12
test _b[BT] + _b[BT_x_CRT34]=0
estadd scalar pv = r(p) 

eststo: reg p BT College BT_x_College if Treatment==3 | Treatment==12
test _b[BT] + _b[BT_x_College]=0
estadd scalar pv = r(p)

eststo: reg p BT more75k BT_x_Income if  Treatment==3 | Treatment==12
test _b[BT] + _b[BT_x_Income]=0
estadd scalar pv = r(p)	

eststo: reg p BT Age BT_x_Age   if Treatment==3 | Treatment==12
test _b[BT] + _b[BT_x_Age]=0
estadd scalar pv  = r(p)

eststo: reg p BT Female BT_x_Female if Treatment==3 | Treatment==12 
test _b[BT] + _b[BT_x_Female]=0
estadd scalar pv  = r(p)

eststo: reg p BT giving BT_x_Altruism if  Treatment==3 | Treatment==12 
test _b[BT] + _b[BT_x_Altruism]=0
estadd scalar pv  = r(p)

esttab, r2 se star (** 0.05 *** 0.01)  b( %12.2f) scalar(pv) drop()
			  
esttab using "OA - Table 4.csv", append r2 se nostar scalar(pv)  b( %12.2f) drop() 
eststo clear

*****
// Table 5
// RD		  
eststo: reg p BT CRT34 BT_x_CRT34   if Treatment==6 | Treatment==14
test _b[BT] + _b[BT_x_CRT34]=0
estadd scalar pv  = r(p)

eststo: reg p BT College BT_x_College if Treatment==6 | Treatment==14 
test _b[BT] + _b[BT_x_College]=0
estadd scalar pv  = r(p)

eststo: reg p BT more75k BT_x_Income if  Treatment==6 | Treatment==14 
test _b[BT] + _b[BT_x_Income]=0
estadd scalar pv  = r(p)

eststo: reg p BT Age BT_x_Age   if Treatment==6 | Treatment==14
test _b[BT] + _b[BT_x_Age]=0
estadd scalar pv  = r(p)

eststo: reg p BT Female BT_x_Female if Treatment==6 | Treatment==14 
test _b[BT] + _b[BT_x_Female]=0
estadd scalar pv  = r(p)

eststo: reg p BT giving BT_x_Altruism if  Treatment==6 | Treatment==14 
test _b[BT] + _b[BT_x_Altruism]=0
estadd scalar pv  = r(p)

// RR		  
eststo: reg p BT CRT34 BT_x_CRT34   if Treatment==5 | Treatment==13
test _b[BT] + _b[BT_x_CRT34]=0
estadd scalar pv  = r(p)

eststo: reg p BT College BT_x_College if Treatment==5 | Treatment==13 
test _b[BT] + _b[BT_x_College]=0
estadd scalar pv  = r(p)

eststo: reg p BT more75k BT_x_Income if  Treatment==5 | Treatment==13 
test _b[BT] + _b[BT_x_Income]=0
estadd scalar pv  = r(p)

eststo: reg p BT Age BT_x_Age   if Treatment==5 | Treatment==13
test _b[BT] + _b[BT_x_Age]=0
estadd scalar pv  = r(p)

eststo: reg p BT Female BT_x_Female if Treatment==5 | Treatment==13 
test _b[BT] + _b[BT_x_Female]=0
estadd scalar pv  = r(p)

eststo: reg p BT giving  BT_x_Altruism if  Treatment==5 | Treatment==13 
test _b[BT] + _b[BT_x_Altruism]=0
estadd scalar pv  = r(p)
  
esttab, r2 se star (** 0.05 *** 0.01)  b( %12.2f) scalar(pv) drop()
			  
esttab using "OA - Table 5.csv", append r2 se nostar scalar(pv)  b( %12.2f) drop() 
eststo clear

*****
// Table 6
// Panel a (remove Trust==0 to make the table in the online appendix)
*First row
tab Trust Treatment if Treatment==2 | Treatment==3, col
*Second row
tab Trust Treatment if Treatment==11 | Treatment==12, col

// Panel b (remove Trust==0 and invert order of columns to make Table 4 in the online appendix)
*First row
tab Trust Treatment if Treatment==5 | Treatment==6, col
* Second row
tab Trust Treatment if Treatment==13 | Treatment==14, col

*****
// Table 7
// DD			  
eststo: reg Trust BT p BT_x_p if  Treatment==2 | Treatment==11 
test _b[BT] + _b[BT_x_p]=0
estadd scalar pv  = r(p)

//DR
eststo: reg Trust BT p BT_x_p if  Treatment==3 | Treatment==12 
test _b[BT] + _b[BT_x_p]=0
estadd scalar pv  = r(p)

// RD		  
eststo: reg Trust BT p BT_x_p if  Treatment==6 | Treatment==14 
test _b[BT] + _b[BT_x_p]=0
estadd scalar pv  = r(p)

// RR		  
eststo: reg Trust BT p BT_x_p if  Treatment==5 | Treatment==13 
test _b[BT] + _b[BT_x_p]=0
estadd scalar pv  = r(p)
  
esttab, r2 se star (** 0.05 *** 0.01)  b( %12.2f) scalar(pv) drop()
			  
esttab using "OA - Table 7.csv", append r2 se nostar scalar(pv)  b( %12.2f) drop() 
eststo clear

