clear all
set more off

//root folder, for example
//cd "C:\Supplementary material\Replication package"

use "RawData.dta", clear 

// Variables

// Supposedly Democrat vs declared democrat
gen   DeclaredDemocrat    = basedonyourpoliticalviewswouldyo==1
gen   DeclaredRepublican  = basedonyourpoliticalviewswouldyo==2
gen   DeclaredIndependent = basedonyourpoliticalviewswouldyo==3
gen   DeclaredOther       = basedonyourpoliticalviewswouldyo==4

gen     MainParties = DeclaredDemocrat==1
replace MainParties = . if basedonyourpoliticalviewswouldyo>=3

label define MainPartiesLabel 0 "Republican" 1 "Democrat" 
label values MainParties MainPartiesLabel

gen Democrat               = MainParties
gen DeclaredPoliticalid    = basedonyourpoliticalviewswouldyo
gen DeclaredPolorientation = whatisyourpoliticalorientation

gen     SurveyDemocrat = DeclaredDemocrat == 1
replace SurveyDemocrat = . if DeclaredIndependent==1 | DeclaredOther==1

label define SurveyDemocratLabel 0 "Republican" 1 "Democrat" 
label values SurveyDemocrat SurveyDemocratLabel


//Variables used
ren youwillreceiveapaymentaccordingt keep
ren youwillreceiveapaymentbasedonyou trust
ren v16 trustworthy
ren youwillreceiveanadditional3ifyou positivebeliefs
ren pleaseanswerthefollowingquestion ball
ren v24 machine
ren v25 lilypads

gen    Trust = trust - 1
recode trustworthy (2 = 0), gen(Trustworthy)
 

gen CorrectBall=ball=="5" | ball=="0.05" ///
                          | ball=="$0.05." ///
						  | ball=="$0.05" ///
						  | ball=="..05" ///
						  | ball==".o5" ///
						  | ball=="0.05" ///
						  | ball=="5 cent" ///
						  | ball=="5 cents" ///
						  | ball=="$..05"
						  				  

gen CorrectMachine=machine=="5" | machine=="5 min" ///
                                | machine=="5 mins" ///
                                | machine=="5 miniutes" ///
								| machine=="5 minutes" ///
								| machine=="5min" ///
								| machine=="5minutes" ///
								| machine=="5 minutes." ///
								| machine=="five minutes"


gen CorrectLily=lilypads=="47" | lilypads=="47 days" ///
                               | lilypads=="47 Days" ///  
							   | lilypads=="47days" ///
							   | lilypads=="forty seven days"
 
gen ScoreCRT=CorrectBall+CorrectMachine+CorrectLily   

************************
//Demographics
************************

encode gender,        gen(Gender)
encode   year,        gen(Year)
encode ethnicity,     gen(Ethnicity)
encode marital,       gen(Marital)
encode english,       gen(English)
encode written,       gen(Written)
encode lannuage_home, gen(Lannuage_home)
encode usliving ,     gen(Usliving)
encode citizenship,   gen(Citizenship)
encode school,        gen(School)
encode education,     gen(Education)
encode employment,    gen(Employment)
encode income,        gen(Income)
encode householdsize, gen(Householdsize)
encode minors,        gen(Minors)
encode politicalview, gen(Politicalview)
encode polorientation,gen(Polorientation)

recode Politicalview (7 = 1) (8 = 2), gen(PoliticalView)
gen    Female = Gender-1 

recode  Year (1 = 11) (2 = 12), gen(YOB)
replace YOB = YOB - 2

tab positivebeliefs, gen(Beliefs)
gen keep5    = keep==5
gen keep4or5 = keep>=4

tab positivebeliefs, gen(beliefs)

//Ethnicity
tab Ethnicity, gen(Ethnia)
ren Ethnia1 White
ren Ethnia2 Black
ren Ethnia3 Hispanic
ren Ethnia4 East_Asian
gen Other_Ethnicity = Ethnia5==1 | Ethnia6==1 | Ethnia7==1 

//Marital
tab Marital, gen(Marital)
ren Marital1 Single
ren Marital2 Partnered
ren Marital3 Married
ren Marital4 Separated
ren Marital5 Divorced
ren Marital6 Widowed

//English
gen FirstLanEnglish = English==1

//Written
tab Written, gen(Written)
ren Written5 SuperbWriting
ren Written4 AboveAverageWriting
ren Written3 AverageWriting
gen BelowAverageWriting = Written==2 | Written==1

//Lannuage_home
tab Lannuage_home, gen(LanHome)
ren LanHome1 LanatHomeEnglish
ren LanHome2 LanatHomeSpanish
ren LanHome3 LanatHomeEast_Asian
gen LanatHomeOther = LanHome4==1 | LanHome5==1

//Usliving
tab Usliving, gen(Usliving)
gen  UsLiving0_5      = Usliving1==1 | Usliving2==1 | Usliving3==1 
gen  UsLiving6_12     = Usliving4==1 | Usliving5==1  
gen  UsLiving13_more  = Usliving6==1 

//Citizenship
gen UsCitizen = Citizenship==1 | Citizenship==3

//School
tab School, gen(School)
ren School1 NoSchool
ren School2 PartTimeSchool
ren School3 FullTimeSchool

//Education
tab Education, gen(Ed)
ren Ed1 HighSchool
ren Ed2 SomeCollege
ren Ed3 Undergrad
ren Ed4 Masters
ren Ed5 Doctoral
ren Ed6 MD_JD_etc
gen AtLeastCollege = Undergrad+Masters+Doctoral+MD_JD_etc

//Employment
tab Employment, gen(Emp)
ren Emp1 Idle
ren Emp2 Unemployed
ren Emp3 WorkLess15hrs
gen WorkBetween16_40hrs = Emp4==1 | Emp5==1
ren Emp6 WorkMore40hrs
gen NotWorking = Idle+Unemployed

//Income
tab Income, gen(In)
gen Less20k          = In1==1 | In2==1
gen Between20k_75k   = In3==1 | In4==1
gen Less75k          = In1==1 | In2==1 | In3==1 | In4==1
gen Between75k_150k  = In5==1 | In6==1
gen Between150k_350k = In7==1 | In8==1
gen More350k         = In9==1  
gen More150k         = Between150k_350k+More350k

//Householdsize
tab Householdsize, gen(House)
ren House3 House3_5
ren House4 House5_more

//Minors
tab Minors, gen(Minor)
ren Minor1 Minor0
ren Minor2 Minor1_2
ren Minor3 Minor3_more

//Polorientation
tab Polorientation, gen(PolOr)
ren PolOr1 VeryLiberal
ren PolOr2 Liberal
ren PolOr3 Moderate
ren PolOr4 Conservative
ren PolOr5 VeryConservative
ren PolOr6 DontKnow

//ScoreCRT
tab ScoreCRT, gen(ScoreCRT)

//
gen UsLiving6_more = UsLiving6_12+UsLiving13_more
gen Graduate       = Masters+Doctoral+MD_JD_etc
gen WorkLess40hrs  = WorkLess15hrs+WorkBetween16_40hrs




*****************
// LABELS
*****************

label define IdeologyLabel 0 "Republican" 1 "Democrat"  
label values SupposedlyDemocrat IdeologyLabel

label define beliefsLabel 1 "0-9%"   2  "10-19%" ///
                          3 "20-29%" 4  "30-39%" ///
						  5 "40-49%" 6  "50-59%" ///
						  7 "60-69%" 8  "70-79%" ///
						  9 "80-89%" 10 "90-100%"
						  
label values positivebeliefs beliefsLabel

label define TreatmentLabel 1 "matched anyone" ///
                            2 "matched Democrat" ///
							3 "matched Republican" ///
							4 "matched anyone" ///
							5 "matched Republican" ///
							6 "matched Democrat" ///
							11 "matched Democrat - b" ///
							12 "matched Republican - b" ///
							13 "matched Republican - b" ///
				            14 "matched Democrat - b" 
							
label values Treatment TreatmentLabel



tab Treatment, gen(treatment)

// Beliefs
gen p = positivebeliefs/10 - 0.05

// Indicator same identity
gen Is = Treatment==2 | Treatment==5 | Treatment==11 | Treatment==13
gen Io = Treatment==3 | Treatment==6 | Treatment==12 | Treatment==14
gen Iu = Treatment==1 | Treatment==4

label define IsLabel 1 "Same Identity" ///
                     0 "Different Identity"  
							
label values Is IsLabel


label define newPartisanshipLabel 1 "Democrat" ///
                             2 "Republican" ///
							 3 "Independent" ///
							 4 "Other" 
							
label values basedonyourpoliticalviewswouldyo newPartisanshipLabel

// Other useful codings
tab YOB, gen(Cohort)
gen     YOB_1931_1950 = Cohort1==1 | Cohort2==1 
gen     YOB_1951_1965 = Cohort3==1 | Cohort4==1
gen     YOB_1966_1975 = Cohort5==1 | Cohort6==1
gen     YOB_1976_1985 = Cohort7==1 | Cohort8==1
gen     YOB_1986_1995 = Cohort9==1 | Cohort10==1

gen     Cohort = 1 if YOB_1931_1950 == 1
replace Cohort = 2 if YOB_1951_1965 == 1
replace Cohort = 3 if YOB_1966_1975 == 1
replace Cohort = 4 if YOB_1976_1985 == 1
replace Cohort = 5 if YOB_1986_1995 == 1

gen     IncomeBracket = In1==1 | In2==1 | In3==1
replace IncomeBracket = 2 if In4==1 | In5==1
replace IncomeBracket = 3 if In6==1 | In7==1
replace IncomeBracket = 4 if In8==1 | In9==1 


gen stronglyDemocrat   = SupposedlyDemocrat==1 & polorientation == "1 Very Liberal"
gen weaklyDemocrat     = SupposedlyDemocrat==1 & (polorientation == "2 Liberal" | polorientation == "3 Moderate" | polorientation == "6 Don't know")
gen stronglyRepublican = SupposedlyDemocrat==0 & polorientation == "5 Very Conservative"
gen weaklyRepublican   = SupposedlyDemocrat==0 & (polorientation == "4 Conservative" | polorientation == "3 Moderate" | polorientation == "6 Don't know")

gen stronglyDemocratAlt   = SupposedlyDemocrat==1 & (polorientation == "1 Very Liberal" | polorientation == "2 Liberal")
gen weaklyDemocratAlt     = SupposedlyDemocrat==1 & (polorientation == "3 Moderate" | polorientation == "6 Don't know")
gen stronglyRepublicanAlt = SupposedlyDemocrat==0 & (polorientation == "5 Very Conservative" | polorientation == "4 Conservative") 
gen weaklyRepublicanAlt   = SupposedlyDemocrat==0 & (polorientation == "3 Moderate" | polorientation == "6 Don't know")

gen SurveyPolorientation = DeclaredPolorientation

gen giving = 5 - keep

gen BeliefsTreatment = Treatment==11|Treatment==12|Treatment==13|Treatment==14

// Useful interactions
gen ScoreCRT34   = ScoreCRT3==1 | ScoreCRT4==1
gen Is_x_CRT34   = Is==1 & ScoreCRT34==1	
gen Is_x_College = Is==1 & AtLeastCollege==1
gen Is_x_Age     = Is==1 & (YOB_1976_1985!=1 & YOB_1986_1995!=1)
gen Is_x_Income  = Is==1 & IncomeBracket!=1
gen Is_x_Female  = Is==1 & Female==1
gen Is_x_Altruism= Is*giving

// Player B Democrat
gen PBD = Treatment==2 | Treatment==6 
gen PBD_x_CRT34   = PBD==1 & ScoreCRT34==1	
gen PBD_x_College = PBD==1 & AtLeastCollege==1
gen PBD_x_Age     = PBD==1 & (YOB_1976_1985!=1 & YOB_1986_1995!=1)
gen PBD_x_Income  = PBD==1 & IncomeBracket!=1
gen PBD_x_Female  = PBD==1 & Female==1
gen PBD_x_Altruism= PBD*giving

// Beliefs treatment interactions
gen BT           = BeliefsTreatment
gen BT_x_CRT34   = BeliefsTreatment==1 & ScoreCRT34==1	
gen BT_x_College = BeliefsTreatment==1 & AtLeastCollege==1
gen BT_x_Age     = BeliefsTreatment==1 & (YOB_1976_1985!=1 & YOB_1986_1995!=1)
gen BT_x_Income  = BeliefsTreatment==1 & IncomeBracket!=1
gen BT_x_Female  = BeliefsTreatment==1 & Female==1
gen BT_x_Altruism= BeliefsTreatment*giving
gen BT_x_sDem    = BeliefsTreatment*stronglyDemocrat
gen BT_x_sRep    = BeliefsTreatment*stronglyRepublican
gen BT_x_p       = BeliefsTreatment*p

// Variables for moderating effects regressions
gen CRT34    = ScoreCRT34==1
gen College  = AtLeastCollege==1
gen Age      = YOB_1976_1985!=1 & YOB_1986_1995!=1
gen more75k  = IncomeBracket!=1
gen Female_  = Female
gen Altruism = giving

gen Democrats = SupposedlyDemocrat // We use the prefix Supposedly, because this is the identification variable coming from the E-lab pre-screen survey

save "DataQJPS.dta", replace

